@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2017 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -52,6 +52,12 @@ has_class_decl_only_def_change(const class_or_union_sptr& first,
 bool
 has_basic_type_name_change(const diff *);
 
+bool
+has_class_or_union_type_name_change(const diff *d);
+
+bool
+has_basic_or_class_type_name_change(const diff *d);
+
 struct filter_base;
 /// Convenience typedef for a shared pointer to filter_base
 typedef shared_ptr<filter_base> filter_base_sptr;
