@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2016 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -50,7 +50,9 @@ bool maybe_get_symlink_target_file_path(const string& file_path,
 bool base_name(string const& path,
 	       string& file_name);
 bool dir_name(string const &path,
-	      string& path_dir_name);
+	      string& path_dir_name,
+	      bool keep_separator_at_end=false);
+void real_path(const string&path, string& realpath);
 bool ensure_dir_path_created(const string&);
 bool ensure_parent_dir_created(const string&);
 ostream& emit_prefix(const string& prog_name, ostream& out);
@@ -60,6 +62,10 @@ bool string_ends_with(const string&, const string&);
 bool string_begins_with(const string&, const string&);
 bool string_is_ascii(const string&);
 bool string_is_ascii_identifier(const string&);
+bool split_string(const string&, const string&, vector<string>&);
+bool string_suffix(const string&, const string&, string&);
+bool sorted_strings_common_prefix(vector<string>&, string&);
+string get_library_version_string();
 
 suppr::type_suppression_sptr
 gen_suppr_spec_from_headers(const string& hdrs_root_dir);
