@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2017 Red Hat, Inc.
+// Copyright (C) 2017-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -601,7 +601,13 @@ leaf_reporter::report(const class_or_union_diff& d,
       // report change
       size_t numchanges =
 	d.class_or_union_diff::get_priv()->sorted_subtype_changed_dm_.size();
-      if (numchanges)
+      size_t num_filtered =
+	d.class_or_union_diff::get_priv()->
+	count_filtered_subtype_changed_dm(/*local_only =*/ true);
+      assert(numchanges >= num_filtered);
+      size_t net_numchanges = numchanges - num_filtered;
+
+      if (net_numchanges)
 	{
 	  report_mem_header(out, subtype_change_kind, "data member", indent);
 	  for (var_diff_sptrs_type::const_iterator it =
@@ -619,7 +625,13 @@ leaf_reporter::report(const class_or_union_diff& d,
 	}
 
       numchanges = d.class_or_union_diff::get_priv()->sorted_changed_dm_.size();
-      if (numchanges)
+      num_filtered =
+	d.class_or_union_diff::get_priv()->
+	count_filtered_changed_dm(/*local_only =*/ true);
+      assert(numchanges >= num_filtered);
+      net_numchanges = numchanges - num_filtered;
+
+      if (net_numchanges)
 	{
 	  report_mem_header(out, change_kind, "data member", indent);
 	  for (var_diff_sptrs_type::const_iterator it =
