@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2017 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -67,6 +67,7 @@
 ABG_BEGIN_EXPORT_DECLARATIONS
 
 #include <abg-ir.h>
+#include "abg-config.h"
 #include "abg-tools-utils.h"
 
 ABG_END_EXPORT_DECLARATIONS
@@ -334,11 +335,15 @@ maybe_get_symlink_target_file_path(const string& file_path,
 /// figure out anything better (for now; maybe we should do something
 /// better than this later ...).
 ///
+/// @param keep_separator_at_end if true, then keep the separator at
+/// the end of the resulting dir name.
+///
 /// @return true upon successful completion, false otherwise (okay,
 /// for now it always return true, but that might change in the future).
 bool
 dir_name(string const& path,
-	 string& dir_name)
+	 string& dir_name,
+	 bool keep_separator_at_end)
 {
   if (path.empty())
     {
@@ -350,6 +355,9 @@ dir_name(string const& path,
   char *r = ::dirname(p);
   dir_name = r;
   free(p);
+  if (keep_separator_at_end
+      && dir_name.length() < path.length())
+    dir_name += "/";
   return true;
 }
 
@@ -378,6 +386,28 @@ base_name(string const &path,
   return true;
 }
 
+/// Return the real path of a given path.
+///
+/// The real path of path 'foo_path' is the same path as foo_path, but
+/// with symlinks and relative paths resolved.
+///
+/// @param path the path to consider.
+///
+/// @param result the computed real_path;
+void
+real_path(const string&path, string& result)
+{
+  if (path.empty())
+    {
+      result.clear();
+      return;
+    }
+
+  char *realp = realpath(path.c_str(), NULL);
+  if (realp)
+    result = realp;
+}
+
 /// Ensures #dir_path is a directory and is created.  If #dir_path is
 /// not created, this function creates it.
 ///
@@ -586,6 +616,182 @@ string_is_ascii_identifier(const string& str)
   return true;
 }
 
+/// Split a given string into substrings, given some delimiters.
+///
+/// @param input_string the input string to split.
+///
+/// @param delims a string containing the delimiters to consider.
+///
+/// @param result a vector of strings containing the splitted result.
+///
+/// @return true iff the function found delimiters in the input string
+/// and did split it as a result.  Note that if no delimiter was found
+/// in the input string, then the input string is added at the end of
+/// the output vector of strings.
+bool
+split_string(const string& input_string,
+	     const string& delims,
+	     vector<string>& result)
+{
+  size_t current = 0, next;
+  bool did_split = false;
+
+  do
+    {
+      // Trim leading white spaces
+      while (current < input_string.size() && isspace(input_string[current]))
+	++current;
+
+      if (current >= input_string.size())
+	break;
+
+      next = input_string.find_first_of(delims, current);
+      if (next == string::npos)
+	{
+	  string s = input_string.substr(current);
+	  if (!s.empty())
+	    result.push_back(input_string.substr(current));
+	  did_split = (current != 0);
+	  break;
+	}
+      string s = input_string.substr(current, next - current);
+      if (!s.empty())
+	{
+	  result.push_back(input_string.substr(current, next - current));
+	  did_split = true;
+	}
+      current = next + 1;
+    }
+  while (next != string::npos);
+
+  return did_split;
+}
+
+/// Get the suffix of a string, given a prefix to consider.
+///
+/// @param input_string the input string to consider.
+///
+/// @param prefix the prefix of the input string to consider.
+///
+/// @param suffix output parameter. This is set by the function to the
+/// the computed suffix iff a suffix was found for prefix @p prefix.
+///
+/// @return true iff the function could find a prefix for the suffix
+/// @p suffix in the input string @p input_string.
+bool
+string_suffix(const string& input_string,
+	      const string& prefix,
+	      string& suffix)
+{
+  // Some basic sanity check before we start hostilities.
+  if (prefix.length() >= input_string.length())
+    return false;
+
+  if (input_string.compare(0, prefix.length(), prefix) != 0)
+    // The input string does not start with the string contained in
+    // the prefix parameter.
+    return false;
+
+  suffix = input_string.substr(prefix.length());
+  return true;
+}
+
+/// Return the prefix that is common to two strings.
+///
+/// @param s1 the first input string to consider.
+///
+/// @param s2 the second input string to consider.
+///
+/// @param result output parameter.  The resulting common prefix found
+/// between @p s1 and @p s2.  This is set iff the function returns
+/// true.
+///
+/// @return true iff @p result was set by this function with the
+/// common prefix of @p s1 and @p s2.
+static bool
+common_prefix(const string& s1, const string& s2, string &result)
+{
+  if (s1.length() == 0 || s2.length() == 0)
+    return false;
+
+  result.clear();
+  for (size_t i = 0; i < s1.length() && i< s2.length(); ++i)
+    if (s1[i] == s2[i])
+      result += s1[i];
+    else
+      break;
+
+  return !result.empty();
+}
+
+/// Find the prefix common to a *SORTED* vector of strings.
+///
+/// @param input_strings a lexycographically sorted vector of
+/// strings.  Please note that this vector absolutely needs to be
+/// sorted for the function to work correctly.  Otherwise the results
+/// are going to be wrong.
+///
+/// @param prefix output parameter.  This is set by this function with
+/// the prefix common to the strings found in @p input_strings, iff
+/// the function returns true.
+///
+/// @return true iff the function could find a common prefix to the
+/// strings in @p input_strings.
+bool
+sorted_strings_common_prefix(vector<string>& input_strings, string& prefix)
+{
+  string prefix_candidate;
+  bool found_prefix = false;
+
+  if (input_strings.size() == 1)
+    {
+      if (dir_name(input_strings.front(), prefix,
+		   /*keep_separator_at_end=*/true))
+	return true;
+      return false;
+    }
+
+  string cur_str;
+  for (vector<string>::const_iterator i = input_strings.begin();
+       i != input_strings.end();
+       ++i)
+    {
+      dir_name(*i, cur_str, /*keep_separator_at_end=*/true);
+      if (prefix_candidate.empty())
+	{
+	  prefix_candidate = cur_str;
+	  continue;
+	}
+
+      string s;
+      if (common_prefix(prefix_candidate, cur_str, s))
+	{
+	  assert(!s.empty());
+	  prefix_candidate = s;
+	  found_prefix = true;
+	}
+    }
+
+  if (found_prefix)
+    {
+      prefix = prefix_candidate;
+      return true;
+    }
+
+  return false;
+}
+
+/// Return the version string of the library.
+///
+/// @return the version string of the library.
+string
+get_library_version_string()
+{
+  string major, minor, revision, version_string;
+  abigail::abigail_get_library_version(major, minor, revision);
+  version_string = major + "." + minor + "." + revision;
+  return version_string;
+}
 
 /// The private data of the @ref temp_file type.
 struct temp_file::priv
@@ -1242,14 +1448,15 @@ bool
 gen_suppr_spec_from_kernel_abi_whitelist(const string& abi_whitelist_path,
 					 suppressions_type& supprs)
 {
-  config whitelist;
+  abigail::ini::config whitelist;
   if (!read_config(abi_whitelist_path, whitelist))
     return false;
 
   bool created_a_suppr = false;
 
-  const config::sections_type &whitelist_sections = whitelist.get_sections();
-  for (config::sections_type::const_iterator s =
+  const ini::config::sections_type &whitelist_sections =
+    whitelist.get_sections();
+  for (ini::config::sections_type::const_iterator s =
 	 whitelist_sections.begin();
        s != whitelist_sections.end();
        ++s)
@@ -1261,7 +1468,7 @@ gen_suppr_spec_from_kernel_abi_whitelist(const string& abi_whitelist_path,
       function_suppression_sptr fn_suppr;
       variable_suppression_sptr var_suppr;
       string function_names_regexp, variable_names_regexp;
-      for (config::properties_type::const_iterator p =
+      for (ini::config::properties_type::const_iterator p =
 	     (*s)->get_properties().begin();
 	   p != (*s)->get_properties().end();
 	   ++p)
