@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2015 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -136,13 +136,15 @@ main(int argc, char **argv)
 
   string file_name = argv[1];
 
-  abigail::translation_unit tu(file_name);
-  if (!abigail::xml_reader::read_translation_unit_from_file(tu))
+  abigail::ir::environment_sptr env(new abigail::ir::environment);
+  abigail::translation_unit_sptr tu;
+  if (!(tu = abigail::xml_reader::read_translation_unit_from_file(file_name,
+								  env.get())))
     {
       cerr << "failed to read " << file_name << "\n";
       return 1;
     }
 
   name_printing_visitor v;
-  tu.traverse(v);
+  tu->traverse(v);
 }
