@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2015 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -104,11 +104,12 @@ main()
 
   for (InOutSpec* s = in_out_specs; s->in_elf_path; ++s)
     {
-      in_elf_path = get_src_dir() + "/tests/" + s->in_elf_path;
+      in_elf_path = string(get_src_dir()) + "/tests/" + s->in_elf_path;
       symbol = s->symbol;
       abisym_options = s->abisym_options;
-      ref_report_path = get_src_dir() + "/tests/" + s->in_report_path;
-      out_report_path = get_build_dir() + "/tests/" + s->out_report_path;
+      ref_report_path = string(get_src_dir()) + "/tests/" + s->in_report_path;
+      out_report_path =
+	string(get_build_dir()) + "/tests/" + s->out_report_path;
 
       if (!ensure_parent_dir_created(out_report_path))
 	{
@@ -118,7 +119,7 @@ main()
 	  continue;
 	}
 
-      abisym = get_build_dir() + "/tools/abisym";
+      abisym = string(get_build_dir()) + "/tools/abisym";
       abisym += " " + abisym_options;
 
       string cmd = abisym + " " + in_elf_path + " " + symbol;
