@@ -18,7 +18,7 @@
 #include <config.h>
 #endif
 
-#define DJB2_START 5381;
+#define DJB2_START 5381
 #define DJB2_HASH(hash, c) (hash = ((hash << 5) + hash) ^ (c)) //|{hash = ((hash << 5) + hash) + c;}
 
 /*
@@ -144,7 +144,7 @@
 /* returns the length of the match. 0 if no match.
   if image_distance = 0, pixel_distance is the distance between the matching pixels.
   Otherwise, it is the offset from the beginning of the referred image */
-static INLINE size_t FNAME(do_match)(SharedDictionary *dict,
+static inline size_t FNAME(do_match)(SharedDictionary *dict,
                                      WindowImageSegment *ref_seg, const PIXEL *ref,
                                      const PIXEL *ref_limit,
                                      WindowImageSegment *ip_seg,  const PIXEL *ip,
